
using System;

namespace zero
{

	namespace netboot
	{
		public class ConfigManager
		{
			private string config_file;	
			private string version_file;	
			private string distroVersion="marty";
			private string distroVersionNum="11.09";
			
			public bool debug;
			public System.Collections.Generic.Dictionary<string,string> options;
			public System.Collections.Generic.Dictionary<string,string> config_vars;
			
			
			public ConfigManager ()
			{
				debug=zero.netboot.Core.getCore().debug;
				config_file="/etc/zero-net-boot/conf.cfg";
				version_file="/etc/zero-net-boot/version.cfg";
				options=new System.Collections.Generic.Dictionary<string, string>();
				config_vars = new System.Collections.Generic.Dictionary<string, string>();
				config_vars["default_save_path"]="/net/isos/";
				config_vars["ftp_daily"]="ftp://arxiu.lliurex.net/pub/isos/" + distroVersionNum + "/daily/";
				config_vars["ftp_stable"]="ftp://arxiu.lliurex.net/pub/isos/" + distroVersionNum + "/releases/";
				config_vars["lliurex_net"]="http://lliurex.net/home/descargas";
				config_vars["default_iso"]="tcos";
				config_vars["installation_enabled"]="true";
				config_vars["language_enabled"]="qcv_ES";
				config_vars["liveuser"]="";
				config_vars["livepasswd"]="";
				config_vars["isos-sources-list"]="local";
				
				try
				{
					readFile();
					check_options();
					printValues();
				}
				catch
				{
					Console.WriteLine("[ConfigManager] Failed to read configuration file");
					writeFile();
					readFile();
					check_options();
				}
			}
			
			public void check_options()
			{
				foreach(System.Collections.Generic.KeyValuePair<string,string> pair in config_vars)
				{
					if (!options.ContainsKey(pair.Key)) 
					{
						options[pair.Key]=pair.Value;
						writeFile();
					}
				}
			}
			
			public void readFile()
			{
				
					System.IO.StreamReader sr=new System.IO.StreamReader(config_file);
					
					string std_out=sr.ReadToEnd();
					string[] list_values=std_out.Split('\n');
		
					foreach(string line in list_values )
					{
						if (line.Contains("="))	
						{
						//	Console.WriteLine(line);
							
							string[] tmp=line.Split('=');
							
							options[tmp[0]]=tmp[1];
						}
					}
				
					try
					{
						System.IO.StreamReader ver=new System.IO.StreamReader(version_file);
						
						string ver_out=ver.ReadToEnd();
						string[] ver_values=ver_out.Split('\n');
			
						foreach(string line in ver_values )
						{
							if (line.Contains("="))	
							{
							//	Console.WriteLine(line);
								
								string[] tmp=line.Split('=');
								
								options[tmp[0]]=tmp[1];
							}
						}
					}
					catch
					{
						Console.WriteLine("[ConfigManager] " + version_file + " is missing");	
						
					}
			}
			
			
			public void writeFile()
			{
			
				System.IO.File.Delete(config_file);
				
				System.IO.StreamWriter sw=new System.IO.StreamWriter(config_file);
				
				foreach(System.Collections.Generic.KeyValuePair<string,string> pair in options)
				{
					if (pair.Key.ToString().Equals("version")) continue;
					sw.WriteLine(pair.Key + "=" + pair.Value);
				}
				sw.Close();
				
			}
			
			
			public void printValues()
			{
				foreach(System.Collections.Generic.KeyValuePair<string,string> pair in options)
				{
					dprint("[ConfigManager] " + pair.Key + " = " + pair.Value);
				}
			}
			
			public void dprint(string txt)
			{
				if (debug)
				{
					Console.WriteLine("[ConfigManager] {0}",txt);
				}	
			}
			
		}
		
	}
}
